\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ArcHandout}
              [2019/09/02 v3.0
               School of Electrical and Information Engineering Handout Class]
% 20190902: JaNee, time for a clean-up. Simplified sizing due to simple
% insistence on the geometry package. See TeXpapersize exercise.
% 20190902 AlanRobertClark@gmail.com
%
% Use as:
% \documentclass(ArcHandout} % a4paper default
% \begin{document}
% \twocolumn
% \course{ELEN3000A---Electromagnetics}
% \title{TUTORIAL 3---Reflections\&S-parameters\vspace{1.5ex}\hrule}
% \makeheads
%
% History comments moved to end.
\RequirePackage[final]{graphicx} % logo.
\PassOptionsToClass{a4paper}{article}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ExecuteOptions{a4paper}
\ProcessOptions\relax
\LoadClass{article}

% Do NOT fiddle with actual parameters, use geometry to provide Handout
% sized full pages!
\RequirePackage[hmargin=25mm,bottom=30mm]{geometry}
\RequirePackage{parskip}

\newcounter{qno}
\newcommand{\zzzc}{}      % Course name generator
\newcommand{\course}[1]{\renewcommand{\zzzc}{#1}}
\renewcommand{\@maketitle}{%
  \newpage{%
    \Large
    \begin{tabular}{p{7mm}l}
      \setlength{\unitlength}{1mm}
      \begin{picture}(0,0)(15,13.5)
        \includegraphics[width=25mm]{ArcSchlLogo}%
      \end{picture}%
      &\textsf{UNIVERSITY OF THE WITWATERSRAND, JOHANNESBURG}\\
      &\textsl{School of Electrical and Information Engineering}\\
      &\smallskip\zzzc
    \end{tabular}

    \smallskip\hrulefill\medskip
  }
  \begin{center}
    {\Large\bf \@title\vspace{2ex}}
  \end{center}
}

\newcommand{\makeheads}{\maketitle}
\newcommand{\omithead}{\renewcommand{\@maketitle}{}}
\title{}\author{}\date{}  % default these to nothing
\newcommand{\question}{\addtocounter{qno}{1}\subsection*{Question \theqno}}
\providecommand{\marks}[1]{\rhfit{\sf(#1~marks)}}

% handout.cls by Alan Robert Clark, a.clark@ee.wits.ac.za, modified from:
%   Handout.cls by Dean Redelinghuys, modified from
%   HANDOUT.STY         I.M. MacLeod, 20 Jan 1989. Rev 1, 4 Mar 1992
%   Custom modifications to the "article" document-style for Electrical
%   Engineering general purpose handouts such as course outlines,
%   laboratory sheets, tutorials and class tests.
%   Intended to be used as a class:
%      \documentclass[11pt]{handout}
%   This style uses article as its base.
%
%   The type size recommended for general use on A4 paper is 11pt, but 10pt
%   or 12pt can also be used. The default page style, viz., plain is assumed.
%

% vim: set filetype=tex:
